@@ -1,16 +1,30 @@
 # Copyright 2016 - 2020  Ternaris.
 # SPDX-License-Identifier: AGPL-3.0-only
 
-from .decorators import InputNameCollision, input, node, select
-from .ioctrl import (Abort, ReaderError, create_group, create_stream, get_logger, get_requested,
-                     get_resource_path, make_file, pull, pull_all, push, set_header)
+from .decorators import InputNameCollisionError, input, node, select
+from .ioctrl import (
+    Abort,
+    ReaderError,
+    ResourceNotFoundError,
+    create_group,
+    create_stream,
+    get_logger,
+    get_requested,
+    get_resource_path,
+    make_file,
+    pull,
+    pull_all,
+    push,
+    set_header,
+)
 from .scanner import DatasetInfo
 
 __all__ = (
     'Abort',
     'DatasetInfo',
-    'InputNameCollision',
+    'InputNameCollisionError',
     'ReaderError',
+    'ResourceNotFoundError',
     'create_group',
     'create_stream',
     'get_logger',
@@ -19,8 +33,8 @@ __all__ = (
     'input',
     'make_file',
     'node',
-    'pull',
     'pull_all',
+    'pull',
     'push',
     'select',
     'set_header',
