@@ -1,10 +1,15 @@
 # Copyright 2020  Ternaris.
 # SPDX-License-Identifier: AGPL-3.0-only
 
+from __future__ import annotations
+
 import functools
 import warnings
 from dataclasses import dataclass
-from typing import Any
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from typing import Any, Optional
 
 
 @dataclass
@@ -12,7 +17,7 @@ class Info:
     module: str
     version: str
     obj: Any
-    msg: str = None
+    msg: Optional[str] = None
 
 
 def make_getattr(module, dct):
@@ -35,7 +40,9 @@ def make_getattr(module, dct):
 
 def deprecated(version, msg=None, name=None):
     """Wrap function to trigger deprecated message upon call."""
+
     def deco(func):
+
         @functools.wraps(func)
         def wrapper(*args, **kw):
             _msg = (
@@ -44,5 +51,7 @@ def deprecated(version, msg=None, name=None):
             )
             warnings.warn(_msg, FutureWarning, stacklevel=2)
             return func(*args, **kw)
+
         return wrapper
+
     return deco
