@@ -4,7 +4,7 @@
 import pytest
 
 
-@pytest.fixture
+@pytest.fixture()
 def tmpdir(tmp_path):
     """We don't want pytest's path implementation."""
     return tmp_path
